@@ -1357,31 +1357,32 @@ static NhlErrorTypes MapWinToData
 	*status = 0;
 	for(i=0; i< n; i++) {
 		if(((xmissing != NULL)&&(*xmissing == x[i]))
-			||((ymissing != NULL)&&(*ymissing == y[i]))
-			||(x[i] < xmin)
-			||(x[i] > xmax)
-			||(y[i] < ymin)
-			||(y[i] > ymax)) {
-
+		   ||((ymissing != NULL)&&(*ymissing == y[i]))) {
 			*status = 1;
 			xout[i]=yout[i]=minstance->trobj.out_of_range;
-	
-
-		} else {
-			c_maptri(x[i],y[i],&(yout[i]),&(xout[i]));
-			if (yout[i] == minstance->trobj.out_of_range) {
+			continue;
+		}	
+		else if  ((x[i] < xmin)||(x[i] > xmax)||(y[i] < ymin)||(y[i] > ymax)) {
+			if (! win_compare_check(mtp,&(x[i]),&(y[i]),xmin,xmax,ymin,ymax)) {
 				*status = 1;
 				xout[i]=yout[i]=minstance->trobj.out_of_range;
+				continue;
 			}
-			else if (xout[i] < mtp->data_xmin) {
-				if (xout[i] + 360 <= mtp->data_xmax + mpDATAEPS) {
-					xout[i] += 360.0;
-				}
+		}
+		c_maptri(x[i],y[i],&(yout[i]),&(xout[i]));
+		if (yout[i] == minstance->trobj.out_of_range) {
+			*status = 1;
+			xout[i]= xmissing != NULL ? *xmissing : minstance->trobj.out_of_range;
+			yout[i]= ymissing != NULL ? *ymissing : minstance->trobj.out_of_range;
+		}
+		else if (xout[i] < mtp->data_xmin) {
+			if (xout[i] + 360 <= mtp->data_xmax + mpDATAEPS) {
+				xout[i] += 360.0;
 			}
-			else if (xout[i] > mtp->data_xmax) {
-				if (xout[i] - 360.0 >= mtp->data_xmin - mpDATAEPS) {
-					xout[i] -= 360.0;
-				}
+		}
+		else if (xout[i] > mtp->data_xmax) {
+			if (xout[i] - 360.0 >= mtp->data_xmin - mpDATAEPS) {
+				xout[i] -= 360.0;
 			}
 		}
 	}
@@ -2494,7 +2495,7 @@ int upordown;
 	xdist = x - x_last;
 	if (xdist > 180.0)
 		x -= 360.0;
-	else if (xdist < -180)
+	else if (xdist < -180.0)
 		x += 360.0;
        
 	xdist = x - x_last;			
@@ -2539,7 +2540,12 @@ int upordown;
 		c_mapitd(yc,xc,1);
 	}
 	c_mapitd(y,x,2);
-	x_last = fmod(x + 180, 360) - 180;
+	/*x_last = fmod(x + 180, 360) - 180;*/
+	x_last = x;
+	if (x_last > 180.0)
+		x_last -= 360.0;
+	else if (x_last < -180.0)
+		x_last += 360.0;
 	y_last = y;
 	xw_last = xw;
 	yw_last = yw;
