@@ -18,9 +18,12 @@ extern int cuErrOpts;
 
 extern int day_of_year(int, int, int, const char*);
 extern int seconds_in_year(int, const char *);
+extern double fraction_of_year (int year, int month, int day, 
+                                int hour, int minute, double second,
+				const char *calendar);
 
 extern void set_all_missing(void *dt, ng_size_t total_size, 
-                            NclScalar missing, int opt);
+                            NclScalar missing, NclBasicDataTypes typd_dt);
 
 NhlErrorTypes cd_calendar_W( void )
 {
@@ -37,12 +40,6 @@ NhlErrorTypes cd_calendar_W( void )
   int has_missing_x;
   NclScalar missing_x, missing_dx;
   NclBasicDataTypes type_x;
-/* 
- * Variables for calculating fraction of year,  if the option is 4.
- */
-  int doy, nsid, total_seconds_in_year, seconds_in_doy, seconds_in_hour;
-  int seconds_in_minute; 
-  double current_seconds_in_year, fraction_of_year;
 
 /*
  * Variables for retrieving attributes from the first argument.
@@ -77,7 +74,7 @@ NhlErrorTypes cd_calendar_W( void )
 /*
  * various
  */
-  int ret, return_missing;
+  int ret, return_all_missing;
   ng_size_t dsizes[1];
   ng_size_t i, total_size_x;
   ng_size_t total_size_date = 0;
@@ -122,7 +119,7 @@ NhlErrorTypes cd_calendar_W( void )
  * The "calendar" option may optionally be set, but it must be equal to
  * one of the recognized calendars.
  */
-  return_missing = 0;
+  return_all_missing = 0;
 
   stack_entry = _NclGetArg(0, 2, DONT_CARE);
   switch (stack_entry.kind) {
@@ -130,7 +127,7 @@ NhlErrorTypes cd_calendar_W( void )
     if (stack_entry.u.data_var->var.att_id != -1) {
       attr_obj = (NclAtt) _NclGetObj(stack_entry.u.data_var->var.att_id);
       if (attr_obj == NULL) {
-        return_missing = 1;
+        return_all_missing = 1;
         break;
       }
     }
@@ -138,14 +135,14 @@ NhlErrorTypes cd_calendar_W( void )
 /*
  * att_id == -1 ==> no attributes specified; return all missing.
  */
-      return_missing = 1;
+      return_all_missing = 1;
       break;
     }
 /* 
  * Check for attributes. If none are specified, then return missing values.
  */
     if (attr_obj->att.n_atts == 0) {
-      return_missing = 1;
+      return_all_missing = 1;
       break;
     }
     else {
@@ -169,7 +166,7 @@ NhlErrorTypes cd_calendar_W( void )
              strcasecmp(ccal,"360_day") && strcasecmp(ccal,"360") &&
              strcasecmp(ccal,"julian")  && strcasecmp(ccal,"none")) {
             NhlPError(NhlWARNING,NhlEUNKNOWN,"cd_calendar: the 'calendar' attribute (%s) is not equal to a recognized calendar. Returning all missing values.",ccal);
-            return_missing = 1;
+            return_all_missing = 1;
           }
         }
         if ((strcmp(attr_list->attname, "units")) == 0) {
@@ -277,12 +274,12 @@ NhlErrorTypes cd_calendar_W( void )
   coerce_missing(type_x,has_missing_x,&missing_x,&missing_dx,NULL);
 
 /* 
- * If we reach this point and return_missing is not 0, then either
+ * If we reach this point and return_all_missing is not 0, then either
  * "units" was invalid or wasn't set, or "calendar" was not a
  * recoginized calendar. We return all missing values in this case.
  */
-  if(return_missing) {
-    set_all_missing(date, total_size_date, missing_date, *option);
+  if(return_all_missing) {
+    set_all_missing(date, total_size_date, missing_date, type_date);
     ret = NclReturnValue(date,ndims_date,dsizes_date,
                           &missing_date,type_date,0);
     NclFree(dsizes_date);
@@ -308,7 +305,7 @@ NhlErrorTypes cd_calendar_W( void )
  * Only check this once.
  */
       if(i == 0 && (cuErrorOccurred && (cuErrOpts & CU_FATAL))) {
-        set_all_missing(date, total_size_date, missing_date, *option);
+        set_all_missing(date, total_size_date, missing_date, type_date);
         ret = NclReturnValue(date,ndims_date,dsizes_date,
                              &missing_date,type_date,0);
         NclFree(dsizes_date);
@@ -322,6 +319,7 @@ NhlErrorTypes cd_calendar_W( void )
  * above are calculated from the fractional part of the hour.
  */
       hour  = (int)comptime.hour;
+
 /*
  * Calculate the return values, based on the input option.
  */
@@ -388,39 +386,7 @@ NhlErrorTypes cd_calendar_W( void )
  *  YYYY.fraction_of_year
  */
       case 4:
-	nsid = 86400;      /* num seconds in a day */
-        if(ccal == NULL) {
-          total_seconds_in_year = seconds_in_year(year,"standard");
-          doy = day_of_year(year,month,day,"standard");
-        }
-        else {
-          total_seconds_in_year = seconds_in_year(year,ccal);
-          doy = day_of_year(year,month,day,ccal);
-        }
-        if(doy > 1) {
-          seconds_in_doy = (doy-1) * nsid;
-        }
-        else {
-          seconds_in_doy = 0;
-        }
-        if(hour > 1) {
-          seconds_in_hour  = (hour-1) * 3600;
-        }
-        else {
-          seconds_in_hour  = 0;
-        }
-        if(minute > 1) {
-          seconds_in_minute  = (minute-1) * 60;
-        }
-        else {
-          seconds_in_minute  = 0;
-        }
-        current_seconds_in_year = seconds_in_doy + 
-          seconds_in_hour + 
-          seconds_in_minute + 
-          second;
-        fraction_of_year = current_seconds_in_year/(double)total_seconds_in_year;
-        ((double*)date)[index_date] = (double)year + fraction_of_year;
+        ((double*)date)[index_date] = (double)year + fraction_of_year(year,month,day,hour,minute,second,ccal);
         break;
       }
     }
@@ -573,42 +539,39 @@ NhlErrorTypes cd_calendar_W( void )
   return(NhlNOERROR);
 }
 
+/*
+ * This function was updated in NCL V6.4.0 to allow
+ * the y/m/d/h/m input to be any type other than
+ * ints, and the output to be int, long, or float,
+ * or double (only double was allowed previously).
+ */
 NhlErrorTypes cd_inv_calendar_W( void )
 {
+/*
+ * Variables for handling NCL variables.
+ */
+  NclStackEntry data;
+  NclMultiDValData tmp_md = NULL;
 /*
  * Input array variables
  */
-  int *year, *month, *day, *hour, *minute;
-  void *second;
-  double *tmp_second = NULL;
+  void *year, *month, *day, *hour, *minute, *second;
+  long *tmp_year = NULL;
+  short *tmp_month = NULL, *tmp_day = NULL;
+  double *tmp_hour = NULL, *tmp_minute = NULL, *tmp_second = NULL;
   NrmQuark *sspec;
-  int *option;
   char *cspec;
-  int ndims_year;
-  ng_size_t dsizes_year[NCL_MAX_DIMENSIONS];
-  int has_missing_year;
-  int ndims_month;
-  ng_size_t dsizes_month[NCL_MAX_DIMENSIONS];
-  int has_missing_month;
-  int ndims_day;
-  ng_size_t dsizes_day[NCL_MAX_DIMENSIONS];
-  int has_missing_day;
-  int ndims_hour;
-  ng_size_t dsizes_hour[NCL_MAX_DIMENSIONS];
-  int has_missing_hour;
-  int ndims_minute;
-  ng_size_t dsizes_minute[NCL_MAX_DIMENSIONS];
-  int has_missing_minute;
-  int ndims_second;
-  ng_size_t dsizes_second[NCL_MAX_DIMENSIONS];
-  int has_missing_second;
-  NclScalar missing_year;
-  NclScalar missing_month;
-  NclScalar missing_day;
-  NclScalar missing_hour;
-  NclScalar missing_minute;
-  NclScalar missing_second;
-  NclBasicDataTypes type_second;
+  ng_size_t *dsizes_year, *dsizes_month, *dsizes_day, *dsizes_hour;
+  ng_size_t *dsizes_minute, *dsizes_second;
+  ng_size_t size_year, size_month, size_day, size_hour, size_minute, size_second;
+  int has_missing_year,has_missing_month,has_missing_day,has_missing_hour;
+  int has_missing_minute,has_missing_second;
+  int ndims_year,ndims_month,ndims_day,ndims_hour,ndims_minute,ndims_second;
+  NclScalar missing_year,missing_month, missing_day, missing_hour;
+  NclScalar missing_minute, missing_second;
+  NclBasicDataTypes type_year,type_month,type_day,type_hour,type_minute,type_second;
+  NclTypeClass type_class_year, type_class_month, type_class_day, type_class_hour;
+  NclTypeClass type_class_minute, type_class_second;
   cdCompTime comptime;
 /*
  * Variables for retrieving attributes from last argument.
@@ -616,14 +579,17 @@ NhlErrorTypes cd_inv_calendar_W( void )
   NclAttList  *attr_list;
   NclAtt  attr_obj;
   NclStackEntry stack_entry;
-  NrmQuark *scal;
-  char   *ccal = NULL;
+  NrmQuark *scal, *sret_type;
+  char   *ccal = NULL, *cret_type;
 /*
  * Output variables.
  */
-  double *x;
+  void *x;
+  double *tmp_x;
   int has_missing_x;
   NclScalar missing_x;
+  NclTypeClass type_x_class;
+  NclBasicDataTypes type_x;
 /*
  * Variables for returning "units" and "calendar" attributes.
  */
@@ -638,75 +604,163 @@ NhlErrorTypes cd_inv_calendar_W( void )
  */
   int ret;
   ng_size_t i, total_size_input;
-  ng_size_t dsizes[1], return_missing;
+  ng_size_t dsizes[1], return_all_missing;
   cdCalenType ctype;
   double fraction;
+  logical is_missing;
 
   /* initialize error flag */
   cuErrorOccurred = 0;
 
 /*
- * Retrieve parameters
+ * Retrieve parameters. We have to do this the "hard" way because of 
+ * handling types that might get coerced to "lower" values (double to 
+ * integer for example).
  *
- * Note any of the pointer parameters can be set to NULL, which
- * implies you don't care about its value.
- * The first size input arrays must be the same dimension sizes.
+ * To make things easier, assign various aspects of multidval to
+ * individual variables.
  */
-  year = (int*)NclGetArgValue(
-           0,
-           8,
-           &ndims_year, 
-           dsizes_year,
-           &missing_year,
-           &has_missing_year,
-           NULL,
-           DONT_CARE);
-  month = (int*)NclGetArgValue(
-           1,
-           8,
-           &ndims_month, 
-           dsizes_month,
-           &missing_month,
-           &has_missing_month,
-           NULL,
-           DONT_CARE);
-  day = (int*)NclGetArgValue(
-           2,
-           8,
-           &ndims_day, 
-           dsizes_day,
-           &missing_day,
-           &has_missing_day,
-           NULL,
-           DONT_CARE);
-  hour = (int*)NclGetArgValue(
-           3,
-           8,
-           &ndims_hour, 
-           dsizes_hour,
-           &missing_hour,
-           &has_missing_hour,
-           NULL,
-           DONT_CARE);
-  minute = (int*)NclGetArgValue(
-           4,
-           8,
-           &ndims_minute, 
-           dsizes_minute,
-           &missing_minute,
-           &has_missing_minute,
-           NULL,
-           DONT_CARE);
-  second = (void*)NclGetArgValue(
-           5,
-           8,
-           &ndims_second, 
-           dsizes_second,
-           &missing_second,
-           &has_missing_second,
-           &type_second,
-           DONT_CARE);
 
+/* Year */  
+  data = _NclGetArg(0,8,DONT_CARE);
+  switch(data.kind) {
+  case NclStk_VAR:
+    tmp_md = _NclVarValueRead(data.u.data_var,NULL,NULL);
+    break;
+  case NclStk_VAL:
+    tmp_md = (NclMultiDValData)data.u.data_obj;
+    break;
+  default:
+    NHLPERROR((NhlFATAL,NhlEUNKNOWN,"Internal error"));
+    return(NhlFATAL);
+  }
+  if(tmp_md == NULL)
+    return(NhlFATAL);
+  year             = tmp_md->multidval.val;
+  ndims_year       = tmp_md->multidval.n_dims;
+  dsizes_year      = tmp_md->multidval.dim_sizes;
+  type_year        = tmp_md->multidval.data_type;
+  type_class_year  = (NclTypeClass)_NclNameToTypeClass(NrmStringToQuark(_NclBasicDataTypeToName(type_year)));
+  size_year        = tmp_md->multidval.type->type_class.size;
+  missing_year     = tmp_md->multidval.missing_value.value;
+  has_missing_year = tmp_md->multidval.missing_value.has_missing;
+/* Month */  
+  data = _NclGetArg(1,8,DONT_CARE);
+  switch(data.kind) {
+  case NclStk_VAR:
+    tmp_md = _NclVarValueRead(data.u.data_var,NULL,NULL);
+    break;
+  case NclStk_VAL:
+    tmp_md = (NclMultiDValData)data.u.data_obj;
+    break;
+  default:
+    NHLPERROR((NhlFATAL,NhlEUNKNOWN,"Internal error"));
+    return(NhlFATAL);
+  }
+  if(tmp_md == NULL)
+    return(NhlFATAL);
+  month             = tmp_md->multidval.val;
+  ndims_month       = tmp_md->multidval.n_dims;
+  dsizes_month      = tmp_md->multidval.dim_sizes;
+  type_month        = tmp_md->multidval.data_type;
+  type_class_month  = (NclTypeClass)_NclNameToTypeClass(NrmStringToQuark(_NclBasicDataTypeToName(type_month)));
+  size_month        = tmp_md->multidval.type->type_class.size;
+  missing_month     = tmp_md->multidval.missing_value.value;
+  has_missing_month = tmp_md->multidval.missing_value.has_missing;
+/* Day */  
+  data = _NclGetArg(2,8,DONT_CARE);
+  switch(data.kind) {
+  case NclStk_VAR:
+    tmp_md = _NclVarValueRead(data.u.data_var,NULL,NULL);
+    break;
+  case NclStk_VAL:
+    tmp_md = (NclMultiDValData)data.u.data_obj;
+    break;
+  default:
+    NHLPERROR((NhlFATAL,NhlEUNKNOWN,"Internal error"));
+    return(NhlFATAL);
+  }
+  if(tmp_md == NULL)
+    return(NhlFATAL);
+  day             = tmp_md->multidval.val;
+  ndims_day       = tmp_md->multidval.n_dims;
+  dsizes_day      = tmp_md->multidval.dim_sizes;
+  type_day        = tmp_md->multidval.data_type;
+  type_class_day  = (NclTypeClass)_NclNameToTypeClass(NrmStringToQuark(_NclBasicDataTypeToName(type_day)));
+  size_day        = tmp_md->multidval.type->type_class.size;
+  missing_day     = tmp_md->multidval.missing_value.value;
+  has_missing_day = tmp_md->multidval.missing_value.has_missing;
+/* Hour */  
+  data = _NclGetArg(3,8,DONT_CARE);
+  switch(data.kind) {
+  case NclStk_VAR:
+    tmp_md = _NclVarValueRead(data.u.data_var,NULL,NULL);
+    break;
+  case NclStk_VAL:
+    tmp_md = (NclMultiDValData)data.u.data_obj;
+    break;
+  default:
+    NHLPERROR((NhlFATAL,NhlEUNKNOWN,"Internal error"));
+    return(NhlFATAL);
+  }
+  if(tmp_md == NULL)
+    return(NhlFATAL);
+  hour             = tmp_md->multidval.val;
+  ndims_hour       = tmp_md->multidval.n_dims;
+  dsizes_hour      = tmp_md->multidval.dim_sizes;
+  type_hour        = tmp_md->multidval.data_type;
+  type_class_hour  = (NclTypeClass)_NclNameToTypeClass(NrmStringToQuark(_NclBasicDataTypeToName(type_hour)));
+  size_hour        = tmp_md->multidval.type->type_class.size;
+  missing_hour     = tmp_md->multidval.missing_value.value;
+  has_missing_hour = tmp_md->multidval.missing_value.has_missing;
+/* Minute */  
+  data = _NclGetArg(4,8,DONT_CARE);
+  switch(data.kind) {
+  case NclStk_VAR:
+    tmp_md = _NclVarValueRead(data.u.data_var,NULL,NULL);
+    break;
+  case NclStk_VAL:
+    tmp_md = (NclMultiDValData)data.u.data_obj;
+    break;
+  default:
+    NHLPERROR((NhlFATAL,NhlEUNKNOWN,"Internal error"));
+    return(NhlFATAL);
+  }
+  if(tmp_md == NULL)
+    return(NhlFATAL);
+  minute             = tmp_md->multidval.val;
+  ndims_minute       = tmp_md->multidval.n_dims;
+  dsizes_minute      = tmp_md->multidval.dim_sizes;
+  type_minute        = tmp_md->multidval.data_type;
+  type_class_minute  = (NclTypeClass)_NclNameToTypeClass(NrmStringToQuark(_NclBasicDataTypeToName(type_minute)));
+  size_minute        = tmp_md->multidval.type->type_class.size;
+  missing_minute     = tmp_md->multidval.missing_value.value;
+  has_missing_minute = tmp_md->multidval.missing_value.has_missing;
+/* Second */  
+  data = _NclGetArg(5,8,DONT_CARE);
+  switch(data.kind) {
+  case NclStk_VAR:
+    tmp_md = _NclVarValueRead(data.u.data_var,NULL,NULL);
+    break;
+  case NclStk_VAL:
+    tmp_md = (NclMultiDValData)data.u.data_obj;
+    break;
+  default:
+    NHLPERROR((NhlFATAL,NhlEUNKNOWN,"Internal error"));
+    return(NhlFATAL);
+  }
+  if(tmp_md == NULL)
+    return(NhlFATAL);
+  second             = tmp_md->multidval.val;
+  ndims_second       = tmp_md->multidval.n_dims;
+  dsizes_second      = tmp_md->multidval.dim_sizes;
+  type_second        = tmp_md->multidval.data_type;
+  type_class_second  = (NclTypeClass)_NclNameToTypeClass(NrmStringToQuark(_NclBasicDataTypeToName(type_second)));
+  size_second        = tmp_md->multidval.type->type_class.size;
+  missing_second     = tmp_md->multidval.missing_value.value;
+  has_missing_second = tmp_md->multidval.missing_value.has_missing;
+
+/* Error checking */
   if(ndims_year != ndims_month || ndims_year != ndims_day    || 
      ndims_year != ndims_hour  || ndims_year != ndims_minute ||
      ndims_year != ndims_second) {
@@ -720,26 +774,10 @@ NhlErrorTypes cd_inv_calendar_W( void )
        dsizes_year[i] != dsizes_hour[i]   || 
        dsizes_year[i] != dsizes_minute[i] ||
        dsizes_year[i] != dsizes_second[i]) {
-      
       NhlPError(NhlFATAL,NhlEUNKNOWN,"cd_inv_calendar: The first six arguments must have the same dimensionality");
       return(NhlFATAL);
     }
   }
-/* 
- * x will contain a _FillValue attribute if any of the input
- * has a _FillValue attribute set.
- */
-  if(has_missing_year || has_missing_month || has_missing_day ||
-     has_missing_hour || has_missing_minute || has_missing_second) {
-    has_missing_x = 1;
-/*
- * Get the default missing value for a double type.
- */
-    missing_x = ((NclTypeClass)nclTypedoubleClass)->type_class.default_mis;
-  }
-  else {
-    has_missing_x = 0;
-  }
 /*
  * Get spec string.
  */
@@ -752,25 +790,14 @@ NhlErrorTypes cd_inv_calendar_W( void )
            NULL,
            NULL,
            1);
-/*
- * Get option.
- */
-  option = (int*)NclGetArgValue(
-           7,
-           8,
-           NULL,
-           NULL,
-           NULL,
-           NULL,
-           NULL,
-           1);
-
 /* 
- * Check the "option" variable to see if it contains a "calendar"
- * attribute.
+ * Check the option argument to see if it contains any
+ * attributes.  The following attributes are supported:
+ *    "calendar"
+ *    "return_type" - Added in V6.4.0
  */
-  return_missing = 0;
-
+  return_all_missing = 0;
+  type_x = NCL_double;
   stack_entry = _NclGetArg(7, 8, DONT_CARE);
   switch (stack_entry.kind) {
   case NclStk_VAR:
@@ -810,7 +837,30 @@ NhlErrorTypes cd_inv_calendar_W( void )
              strcasecmp(ccal,"360_day") && strcasecmp(ccal,"360") &&
              strcasecmp(ccal,"julian")  && strcasecmp(ccal,"none")) {
             NhlPError(NhlWARNING,NhlEUNKNOWN,"cd_inv_calendar: the 'calendar' attribute is not equal to a recognized calendar. Returning all missing values.");
-            return_missing = has_missing_x = 1;
+            return_all_missing = 1;
+          }
+        }
+        if ((strcmp(attr_list->attname, "return_type")) == 0) {
+          sret_type = (NrmQuark *) attr_list->attvalue->multidval.val;
+          cret_type = NrmQuarkToString(*sret_type);
+          if(strcasecmp(cret_type,"double") && strcasecmp(cret_type,"float") &&
+             strcasecmp(cret_type,"long") &&
+             strcasecmp(cret_type,"integer") && strcasecmp(cret_type,"int")) {
+            NhlPError(NhlWARNING,NhlEUNKNOWN,"cd_inv_calendar: the return_type attribute can only be set to 'double', 'float', 'long', or 'integer'.\nWill default to 'double'.");
+          }
+          else {
+            if(!strcasecmp(cret_type,"double")) {
+              type_x = NCL_double;
+            }
+            else if(!strcasecmp(cret_type,"float")) {
+              type_x = NCL_float;
+            }
+            else if(!strcasecmp(cret_type,"long")) {
+              type_x = NCL_long;
+            }
+            else if(!strcasecmp(cret_type,"integer") || !strcasecmp(cret_type,"int")) {
+              type_x = NCL_int;
+            }
           }
         }
         attr_list = attr_list->next;
@@ -838,36 +888,200 @@ NhlErrorTypes cd_inv_calendar_W( void )
 
 /*
  * Calculate total size of input arrays, and size and dimensions for
- * output array, and alloc memory for output array.
+ * output array, and alloc memory for output array. As of NCL V6.4.0,
+ * the output type can be double, float, long, or integer.
  */
   total_size_input = 1;
   for( i = 0; i < ndims_year; i++ ) total_size_input *= dsizes_year[i];
 
-  x = (double *)calloc(total_size_input,sizeof(double));
-
+  if(type_x == NCL_double) {
+    x = (double *)calloc(total_size_input,sizeof(double));
+  }
+  else if(type_x == NCL_float) {
+    x = (float *)calloc(total_size_input,sizeof(float));
+  }
+  else if(type_x == NCL_long) {
+    x = (long *)calloc(total_size_input,sizeof(long));
+  }
+  else if(type_x == NCL_int) {
+    x = (int *)calloc(total_size_input,sizeof(int));
+  }
   if( x == NULL ) {
     NhlPError(NhlFATAL,NhlEUNKNOWN,"cd_inv_calendar: Unable to allocate memory for output array");
     return(NhlFATAL);
   }
 /*
- * Create tmp array for coercing second to double if necessary.
+ * Create tmp array for holding double output values.
  */
+  if(type_x != NCL_double) {
+    tmp_x = (double*)calloc(1,sizeof(double));
+    if(tmp_x == NULL) {
+      NhlPError(NhlFATAL,NhlEUNKNOWN,"cd_inv_calendar: Unable to allocate memory for temporary output array");
+      return(NhlFATAL);
+    }
+  }
+
+/*
+ * x will contain a _FillValue attribute if there's bad input, or any of the input
+ * has a _FillValue attribute set. return_all_missing is a flag to indicate whether
+ * all values should be set to missing.
+ */
+  if(return_all_missing || has_missing_year || has_missing_month || has_missing_day ||
+     has_missing_hour || has_missing_minute || has_missing_second) {
+    has_missing_x = 1;
+/*
+ * Get the default missing value for the return type.
+ */
+    if(type_x == NCL_double) {
+      missing_x = ((NclTypeClass)nclTypedoubleClass)->type_class.default_mis;
+    }
+    else if(type_x == NCL_float) {
+      missing_x = ((NclTypeClass)nclTypefloatClass)->type_class.default_mis;
+    }
+    else if(type_x == NCL_long) {
+      missing_x = ((NclTypeClass)nclTypelongClass)->type_class.default_mis;
+    }
+    else if(type_x == NCL_int) {
+      missing_x = ((NclTypeClass)nclTypeintClass)->type_class.default_mis;
+    }
+  }
+  else {
+    has_missing_x = 0;
+  }
+
+  if(return_all_missing) {
+    set_all_missing(x, total_size_input, missing_x, type_x);
+    ret = NclReturnValue(x,ndims_year,dsizes_year,&missing_x,
+                         type_x,0);
+    if(type_x != NCL_double) NclFree(tmp_x);
+    return(ret);
+  }
+/*
+ * Create tmp arrays for coercing input arrays to the appropriate types.
+ * Before NCL V6.4.0, year, month, day, hour, minute all had to be integers.
+ */
+  if(type_year != NCL_long) {
+    tmp_year = (long*)calloc(1,sizeof(long));
+    if(tmp_year == NULL) {
+      NhlPError(NhlFATAL,NhlEUNKNOWN,"cd_inv_calendar: Unable to allocate memory for coercing year array to long");
+      return(NhlFATAL);
+    }
+  }
+  if(type_month != NCL_short) {
+    tmp_month = (short*)calloc(1,sizeof(short));
+    if(tmp_month == NULL) {
+      NhlPError(NhlFATAL,NhlEUNKNOWN,"cd_inv_calendar: Unable to allocate memory for coercing month array to short");
+      return(NhlFATAL);
+    }
+  }
+  if(type_day != NCL_short) {
+    tmp_day = (short*)calloc(1,sizeof(short));
+    if(tmp_day == NULL) {
+      NhlPError(NhlFATAL,NhlEUNKNOWN,"cd_inv_calendar: Unable to allocate memory for coercing day array to short");
+      return(NhlFATAL);
+    }
+  }
+  if(type_hour != NCL_double) {
+    tmp_hour = (double*)calloc(1,sizeof(double));
+    if(tmp_hour == NULL) {
+      NhlPError(NhlFATAL,NhlEUNKNOWN,"cd_inv_calendar: Unable to allocate memory for coercing hour array to double");
+      return(NhlFATAL);
+    }
+  }
+  if(type_minute != NCL_double) {
+    tmp_minute = (double*)calloc(1,sizeof(double));
+    if(tmp_minute == NULL) {
+      NhlPError(NhlFATAL,NhlEUNKNOWN,"cd_inv_calendar: Unable to allocate memory for coercing minute array to double");
+      return(NhlFATAL);
+    }
+  }
   if(type_second != NCL_double) {
     tmp_second = (double*)calloc(1,sizeof(double));
     if(tmp_second == NULL) {
-      NhlPError(NhlFATAL,NhlEUNKNOWN,"cd_inv_calendar: Unable to allocate memory for coercing second array to double precision");
+      NhlPError(NhlFATAL,NhlEUNKNOWN,"cd_inv_calendar: Unable to allocate memory for coercing second array to double");
       return(NhlFATAL);
     }
   }
 
 /* 
- * Loop through each data value, and call Udunits routine.
+ * Loop through each data value, and call cdComp2Rel routine.
  */ 
   for( i = 0; i < total_size_input; i++ ) {
+    is_missing = False;
 /*
- * Coerce "second" to double, since this is what the original Udunits
- * routine is expecting. 
+ * Check for missing values. If any of the input is missing, then 
+ * the output should be set to missing for the same loop index. 
  */
+    if(has_missing_year) {
+       _Ncleq(type_class_year,&is_missing,&(((char*)year)[i*size_year]),&missing_year,NULL,NULL,1,1);
+    }
+    if(!is_missing && has_missing_month) {
+       _Ncleq(type_class_month,&is_missing,&(((char*)month)[i*size_month]),&missing_month,NULL,NULL,1,1);
+    }
+    if(!is_missing && has_missing_day) {
+       _Ncleq(type_class_day,&is_missing,&(((char*)day)[i*size_day]),&missing_day,NULL,NULL,1,1);
+    }
+    if(!is_missing && has_missing_hour) {
+       _Ncleq(type_class_hour,&is_missing,&(((char*)hour)[i*size_hour]),&missing_hour,NULL,NULL,1,1);
+    }
+    if(!is_missing && has_missing_minute) {
+       _Ncleq(type_class_minute,&is_missing,&(((char*)minute)[i*size_minute]),&missing_minute,NULL,NULL,1,1);
+    }
+    if(!is_missing && has_missing_second) {
+       _Ncleq(type_class_second,&is_missing,&(((char*)second)[i*size_second]),&missing_second,NULL,NULL,1,1);
+    }
+    if(is_missing) {
+      has_missing_x = 1;
+      if(type_x == NCL_double) {
+         ((double*)x)[i] = missing_x.doubleval;
+      }
+      else if(type_x == NCL_float) {
+        ((float*)x)[i] = missing_x.floatval;
+      }
+      else if(type_x == NCL_long) {
+        ((long*)x)[i] = missing_x.longval;
+      }
+      else if(type_x == NCL_int) {
+        ((int*)x)[i] = missing_x.intval;
+      }
+      continue;
+    }
+/*
+ * No missing values detected, so coerce year, month, day, hour, 
+ * minute to the appropriate type.
+ */
+    if(type_year != NCL_long) {
+      force_subset_input_long(year,tmp_year,i,type_year,1);
+    }
+    else {
+      tmp_year = &((long*)year)[i];
+    }
+    if(type_month != NCL_short) {
+      force_subset_input_short(month,tmp_month,i,type_month,1);
+    }
+    else {
+      tmp_month = &((short*)month)[i];
+    }
+    if(type_day != NCL_short) {
+      force_subset_input_short(day,tmp_day,i,type_day,1);
+    }
+    else {
+      tmp_day = &((short*)day)[i];
+    }
+    if(type_hour != NCL_double) {
+      coerce_subset_input_double(hour,tmp_hour,i,type_hour,1,
+                                 has_missing_hour,&missing_hour,NULL);
+    }
+    else {
+      tmp_hour = &((double*)hour)[i];
+    }
+    if(type_minute != NCL_double) {
+      coerce_subset_input_double(minute,tmp_minute,i,type_minute,1,
+                                 has_missing_minute,&missing_minute,NULL);
+    }
+    else {
+      tmp_minute = &((double*)minute)[i];
+    }
     if(type_second != NCL_double) {
       coerce_subset_input_double(second,tmp_second,i,type_second,1,
                                  has_missing_second,&missing_second,NULL);
@@ -876,48 +1090,60 @@ NhlErrorTypes cd_inv_calendar_W( void )
       tmp_second = &((double*)second)[i];
     }
 
-    if(!return_missing && (!has_missing_year   ||
-        (has_missing_year && year[i]       != missing_year.intval))   &&
-       (!has_missing_month ||
-         (has_missing_month && month[i]    != missing_month.intval))  &&
-       (!has_missing_day ||
-         (has_missing_day && day[i]        != missing_day.intval))    &&
-       (!has_missing_hour ||
-         (has_missing_hour  && hour[i]     != missing_hour.intval))   &&
-       (!has_missing_minute ||
-         (has_missing_minute && minute[i]  != missing_minute.intval)) &&
-       (!has_missing_second ||
-        (has_missing_second && *tmp_second != missing_second.doubleval)) ) {
+    if(type_x == NCL_double) tmp_x = &((double*)x)[i];
 
-      fraction       = (double)minute[i]/60. + *tmp_second/3600.;
-      comptime.year  = (long)year[i];
-      comptime.month = (short)month[i];
-      comptime.day   = (short)day[i];
-      comptime.hour  = (double)hour[i] + fraction;
-      (void)cdComp2Rel(ctype,comptime,cspec,&x[i]);
+    fraction       = *tmp_minute/60. + *tmp_second/3600.;
+    comptime.year  = *tmp_year;
+    comptime.month = *tmp_month;
+    comptime.day   = *tmp_day;
+    comptime.hour  = *tmp_hour + fraction;
+    (void)cdComp2Rel(ctype,comptime,cspec,tmp_x);
 /*
  * Return all missing values if we encounter a fatal error.
  */
-      if(i == 0 && (cuErrorOccurred && (cuErrOpts & CU_FATAL))) {
-        set_all_missing(x, total_size_input, missing_x, 1);
-        ret = NclReturnValue(x,ndims_year,dsizes_year,&missing_x,
-                             NCL_double,0);
-        if(type_second != NCL_double) NclFree(tmp_second);
-        return(ret);
-      }
+    if(i == 0 && (cuErrorOccurred && (cuErrOpts & CU_FATAL))) {
+      set_all_missing(x, total_size_input, missing_x, type_x);
+      ret = NclReturnValue(x,ndims_year,dsizes_year,&missing_x,
+                           type_x,0);
+      if(type_year   != NCL_long)   NclFree(tmp_year);
+      if(type_month  != NCL_short)  NclFree(tmp_month);
+      if(type_day    != NCL_short)  NclFree(tmp_day);
+      if(type_hour   != NCL_double) NclFree(tmp_hour);
+      if(type_minute != NCL_double) NclFree(tmp_minute);
+      if(type_second != NCL_double) NclFree(tmp_second);
+      if(type_x      != NCL_double) NclFree(tmp_x);
+      return(ret);
     }
-    else {
-      x[i]  = missing_x.doubleval;
+/*
+ * Copy output values from temporary tmp_x to x. The
+ * only types possible are double, float, long, or int.
+ * If double, then no coercion necessary.
+ */
+    if(type_x == NCL_float) {
+      coerce_output_float_only(x,tmp_x,1,i);
+    }
+    if(type_x == NCL_long) {
+      coerce_output_long_only(x,tmp_x,1,i);
+    }
+    else if(type_x == NCL_int) {
+      coerce_output_int_only(x,tmp_x,1,i);
     }
   }
 
+  if(type_year   != NCL_long)   NclFree(tmp_year);
+  if(type_month  != NCL_short)  NclFree(tmp_month);
+  if(type_day    != NCL_short)  NclFree(tmp_day);
+  if(type_hour   != NCL_double) NclFree(tmp_hour);
+  if(type_minute != NCL_double) NclFree(tmp_minute);
   if(type_second != NCL_double) NclFree(tmp_second);
+  if(type_x      != NCL_double) NclFree(tmp_x);
 
 /*
  * Set up variable to return.
  */
+  type_x_class = (NclTypeClass)_NclNameToTypeClass(NrmStringToQuark(_NclBasicDataTypeToName(type_x)));
   if(has_missing_x) {
-        return_md = _NclCreateVal(
+       return_md = _NclCreateVal(
                             NULL,
                             NULL,
                             Ncl_MultiDValData,
@@ -928,7 +1154,7 @@ NhlErrorTypes cd_inv_calendar_W( void )
                             dsizes_year,
                             TEMPORARY,
                             NULL,
-                            (NclObjClass)nclTypedoubleClass
+                            (NclObjClass)type_x_class
                             );
   }
   else {
@@ -943,7 +1169,7 @@ NhlErrorTypes cd_inv_calendar_W( void )
                             dsizes_year,
                             TEMPORARY,
                             NULL,
-                            (NclObjClass)nclTypedoubleClass
+                            (NclObjClass)type_x_class
                             );
   }
 
@@ -1042,27 +1268,26 @@ NhlErrorTypes cd_inv_calendar_W( void )
 }
 
 void set_all_missing(void *dt, ng_size_t total_size, 
-                     NclScalar missing, int opt)
+                     NclScalar missing, NclBasicDataTypes type_dt)
 {
   ng_size_t i;
 
-  if(opt == 0) {
-    for(i = 0; i < total_size; i++ ) {
-      ((float*)dt)[i] = missing.floatval;
-    }
-  }
-  else if(opt == -5) {
-    /* identical to option=0, except returns ints */
-    for(i = 0; i < total_size; i++ ) {
-      ((int*)dt)[i] = missing.intval;
-    }
-  }
-  else if(opt >= 1 && opt <= 4) {
+  if(type_dt == NCL_double) {
     for(i = 0; i < total_size; i++ ) {
       ((double*)dt)[i] = missing.doubleval;
     }
   }
-  else if(opt >= -3 && opt <= -1) {
+  else if(type_dt == NCL_float) {
+    for(i = 0; i < total_size; i++ ) {
+      ((float*)dt)[i] = missing.floatval;
+    }
+  }
+  else if(type_dt == NCL_long) {
+    for(i = 0; i < total_size; i++ ) {
+      ((long*)dt)[i] = missing.longval;
+    }
+  }
+  else if(type_dt == NCL_int) {
     for(i = 0; i < total_size; i++ ) {
       ((int*)dt)[i] = missing.intval;
     }
