@@ -50,29 +50,31 @@ NhlErrorTypes conform_W( void )
  */
   void *x;
   NclStackEntry data;
-  int *cnfrm_dims;
+  int *conform_indexes, *tmp_conform_indexes;
   NclMultiDValData tmp_md = NULL;
   int ndims_x;
   ng_size_t dsizes_x[NCL_MAX_DIMENSIONS];
-  ng_size_t dsizes_conform[NCL_MAX_DIMENSIONS];
   NclBasicDataTypes type_x;
+  ng_size_t num_conform_indexes;
 
 /*
  * Output array variables
  */
   void *conform;
   int ndims;
+  NclScalar missing_conform;
 /*
  * various
  */
-  int scalar_tmp_md, copy_scalar = 0;
   ng_size_t i, j;
+  logical is_scalar_arr, is_same_arr, is_degen_arr;
   ng_size_t new_position, size_conform, conform_pos;
-  int type_size;
+  int ic, num_degen_dims, type_size;
   ng_size_t *skip_x = NULL;
   ng_size_t *skip_c = NULL;
   ng_size_t *indices = NULL;
   int ret;
+
 /*
  * Retrieve parameters
  *
@@ -95,73 +97,182 @@ NhlErrorTypes conform_W( void )
     tmp_md = _NclVarValueRead(data.u.data_var,NULL,NULL);
     break;
   case NclStk_VAL:
-    tmp_md = (NclMultiDValData)data.u.data_obj;
+    tmp_md = data.u.data_obj;
     break;
   default:
     NhlPError(NhlFATAL,NhlEUNKNOWN,"conform: invalid first input argument.");
     return(NhlFATAL);
   }
 
-  cnfrm_dims = (int*)NclGetArgValue(
+  conform_indexes = (int*)NclGetArgValue(
            2,
            3,
            NULL,
-           dsizes_conform,
+           &num_conform_indexes,
            NULL,
            NULL,
            NULL,
            DONT_CARE);
 
 /*
- * Check if we're dealing with the special case of where the second
- * argument is a scalar, and the third argument is -1.  If this 
- * is true, then the scalar value will be copied to every 
- * element of the new array.
- */
-  scalar_tmp_md = is_scalar(tmp_md->multidval.n_dims,
-                            tmp_md->multidval.dim_sizes);
-
-  if(scalar_tmp_md && cnfrm_dims[0] == -1) copy_scalar = 1;
+ * If the array-to-be-conformed is a scalar or an array with all 
+ * degenerate dimensions, then this is a special case that we need 
+ * to handle separately. It will be treated as a single value that 
+ * needs to be propagated to whatever the dimensions are of the 
+ * array-to-be-conformed-to.
+ */ 
+  is_scalar_arr = is_scalar_array(tmp_md->multidval.n_dims,
+                                  tmp_md->multidval.dim_sizes);
 
+  is_same_arr = is_degen_arr = False;
 /*
- * If not dealing with the special scalar case, then the number of
- * dimensions of the second argument must be the same as the length
- * of the third argument.
- */
-  if(!copy_scalar && tmp_md->multidval.n_dims != dsizes_conform[0]) {
-    NhlPError(NhlFATAL,NhlEUNKNOWN,"conform: The array to be conformed must have the same number of dimensions as indicated by the length of the last argument");
-    return(NhlFATAL);
-  }
-
-/*
- * If not a scalar situation, check for errors:
- *
- *    1. The dimension indices indicated by the third argument must
+ * If NOT dealing with the special conform_indexes=-1 case, then do some error checking:
+ *    1. The number of dimensions of the second argument must be the 
+ *       same as the length of the third argument.
+ *    2. The dimension indices indicated by the third argument must
  *       be in the range of the dimension indices of x (i.e. if x is
- *       only 3-dimensional, then one of the indices in the 3rd
- *       argument cannot be a "4").
- *    2. The dimensions indices indicated by the third argument must
+ *       only 3-dimensional, then none of the indices in the 3rd
+ *       argument can be greater than 3).
+ *    3. The dimensions indices indicated by the third argument must
  *       be unique and increasing.
  *    4. The dimensions sizes of the second argument must be the same
  *       as those indicated by the third argument.
  */
-  if(!copy_scalar) {
-    for(i = 0; i < dsizes_conform[0]; i++ ) {
-      if(cnfrm_dims[i] < 0 || cnfrm_dims[i] > (ndims_x-1)) {
+  if(conform_indexes[0] != -1) {
+    if(tmp_md->multidval.n_dims != num_conform_indexes) {
+      NhlPError(NhlFATAL,NhlEUNKNOWN,"conform: The array to be conformed must have the same number of dimensions as indicated by the length of the last argument");
+      return(NhlFATAL);
+    }
+    for(i = 0; i < num_conform_indexes; i++ ) {
+      if(conform_indexes[i] < 0 || conform_indexes[i] > (ndims_x-1)) {
         NhlPError(NhlFATAL,NhlEUNKNOWN,"conform: the third argument contains a dimension that is out-of-range of the dimensions of x");
         return(NhlFATAL);
       }
       if(i > 0) {
-        if(cnfrm_dims[i-1] >= cnfrm_dims[i]) {
+        if(conform_indexes[i-1] >= conform_indexes[i]) {
           NhlPError(NhlFATAL,NhlEUNKNOWN,"conform: The dimensions specified by the third argument must be increasing");
           return(NhlFATAL);
         }
       }
-      if(dsizes_x[cnfrm_dims[i]] != tmp_md->multidval.dim_sizes[i] ) {
-        NhlPError(NhlFATAL,NhlEUNKNOWN,"conform: the dimensions sizes of the second argument do not match those indicated by the third argument");
+/*
+ * In NCL V6.4.0, if any of the array-to-be-conformed dimensions are 
+ * degenerate (equal to 1), then this is considered okay no matter
+ * what the dimension size of the array-being-conformed-to is.
+ */
+      if(dsizes_x[conform_indexes[i]] != tmp_md->multidval.dim_sizes[i] && tmp_md->multidval.dim_sizes[i] != 1) {
+        NhlPError(NhlFATAL,NhlEUNKNOWN,"conform: the dimension sizes of the second argument do not match those indicated by the third argument");
         return(NhlFATAL);
       }
     }
+  }
+  else {
+/*
+ * This section does some error checking for the special case of
+ *  conform_indexes = -1.
+ *
+ * You can only use -1 for the third argument if the array you are 
+ * conforming meets one of the following conditions: 
+ *
+ *    1. It's the same size as the array you are conforming to (is_same_arr).
+ *    2. It's an array with some degenerate dimensions, but the other
+ *       dimensions match the array you are conforming to (is_degen_arr).
+ *    3. It's an array with all degenerate dimensions or a scalar (is_scalar_arr)
+ *
+ *    #2 was a feature added in NCL V6.4.0. For example, you can conform
+ *    a 3 x 1 x 5 array to a 3 x 4 x 5 array, using either -1 or (/0,1,2/)
+ *    for the third argument.
+ */
+    if(tmp_md->multidval.n_dims == ndims_x) {
+      is_same_arr = is_degen_arr = True;
+      i = 0;
+      while (i < ndims_x && (is_same_arr || (!is_same_arr && is_degen_arr))) {
+        if(is_same_arr && tmp_md->multidval.dim_sizes[i] != dsizes_x[i]) {
+          is_same_arr  = False;
+          is_degen_arr = True;
+        }
+        if(is_degen_arr && tmp_md->multidval.dim_sizes[i] != dsizes_x[i] && 
+           tmp_md->multidval.dim_sizes[i] != 1) {
+          is_degen_arr = False;
+        }
+        i++;
+      }
+    }
+    if(!is_scalar_arr && !is_same_arr && !is_degen_arr) {
+      NhlPError(NhlFATAL,NhlEUNKNOWN,"conform: if the third argument is -1, then second argument must either be a scalar, an array of the same dimensionality as indicated by the first argument, or an array with all singleton dimensions.");
+      return(NhlFATAL);
+    }
+  }
+
+/*
+ * If the array-to-be-conformed is not ALL degenerate dimensions, then
+ * count the number of degenerate dimensions so we can remove them later.
+ */
+  num_degen_dims = 0;
+  if(!is_scalar_arr) {
+    for(i = 0;i < tmp_md->multidval.n_dims; i++) 
+      if(tmp_md->multidval.dim_sizes[i] == 1) num_degen_dims++;
+  }
+
+/* 
+ * If there are degenerate dimensions, then remove them from the 
+ * input conform_indexes.
+ *
+ * What happens in the code below is if the array to be conformed to
+ * is 3 x 4 x 5, and the array to be conformed is 3 x 1 x 5, then
+ * the array to be conformed will be treated as a 3 x 5 array, and
+ * and hence conform_indexes will be set to (/0,2/). 
+ */
+  if(num_degen_dims > 0) {
+ /*
+  * If there are degenerate dimensions and third argument = -1,
+  * then use first argument as the dimension indexes, but 
+  * with the degenerate dimensions removed.
+  */
+    if(conform_indexes[0] == -1) {
+      num_conform_indexes = tmp_md->multidval.n_dims-num_degen_dims;
+      tmp_conform_indexes = (int*)NclMalloc(num_conform_indexes*sizeof(int));
+      ic = 0;
+      for(i = 0; i < tmp_md->multidval.n_dims; i++) {
+        if(tmp_md->multidval.dim_sizes[i] != 1) tmp_conform_indexes[ic++] = i;
+      }
+    }
+    else {
+ /*
+  * If there are degenerate dimensions and the third argument was a 
+  * list of indexes, then remove any indexes that reference 
+  * degenerate dimensions.
+  */
+      tmp_conform_indexes = (int*)NclMalloc((num_conform_indexes-num_degen_dims)*sizeof(int));
+      ic = 0;
+      for(i = 0; i < num_conform_indexes; i++) {
+        if(tmp_md->multidval.dim_sizes[i] != 1) tmp_conform_indexes[ic++] = conform_indexes[i];
+      }
+      num_conform_indexes = num_conform_indexes-num_degen_dims;
+    }
+  }
+  else {
+    if(conform_indexes[0] == -1) {
+ /*
+  * If there are no degenerate dimensions and third argument = -1,
+  * then use the dimension indexes of the first argument as the 
+  * conform dimension indexes. 
+  */
+      num_conform_indexes = tmp_md->multidval.n_dims;
+      tmp_conform_indexes = (int*)NclMalloc(num_conform_indexes*sizeof(int));
+      for(i = 0; i < tmp_md->multidval.n_dims; i++) {
+        tmp_conform_indexes[i] = i;
+      }
+    }
+    else {
+ /*
+  * If there are no degenerate dimensions and the third argument is a
+  * list of indexes, then simply point to this list of indexes.
+  */
+      tmp_conform_indexes = conform_indexes;
+    }
+  }
+
+  if(!is_scalar_arr && !is_same_arr) {
 /*
  * Create an array to hold the number of linear elements you have to
  * skip over when you increment a particular index.
@@ -173,8 +284,8 @@ NhlErrorTypes conform_W( void )
  * and so on.
  */
     skip_x  = (ng_size_t*)calloc(ndims_x,sizeof(ng_size_t));
+    skip_c  = (ng_size_t*)calloc(num_conform_indexes,sizeof(ng_size_t)); 
     indices = (ng_size_t*)calloc(ndims_x,sizeof(ng_size_t));
-    skip_c  = (ng_size_t*)calloc(dsizes_conform[0],sizeof(ng_size_t));
 
     size_conform = dsizes_x[ndims_x-1];
     skip_x[ndims_x-1] = 1; 
@@ -183,16 +294,16 @@ NhlErrorTypes conform_W( void )
       skip_x[i] = skip_x[i+1]*dsizes_x[i+1];
       size_conform  *= dsizes_x[i];
     }
-    skip_c[dsizes_conform[0]-1] = 1;
-    for(i = dsizes_conform[0]-2; i >= 0; i--) {
-      skip_c[i] = skip_c[i+1]*dsizes_x[cnfrm_dims[i+1]];
+    skip_c[num_conform_indexes-1] = 1;
+    for(i = num_conform_indexes-2; i >= 0; i--) {
+      skip_c[i] = skip_c[i+1]*dsizes_x[tmp_conform_indexes[i+1]];
     }
     ndims  = ndims_x;
   }
   else {
 /*
- * This is the scalar case. The output array will be the size of
- * the dimensions given.
+ * This is the case where the third argument is -1. The output array will
+ * be the size of the dimensions given.
  */
     ndims  = ndims_x;
     size_conform = 1;
@@ -211,9 +322,9 @@ NhlErrorTypes conform_W( void )
   }
 
   type_size = tmp_md->multidval.type->type_class.size;
-  if(!copy_scalar) {
+  if(!is_scalar_arr && !is_same_arr) {
 /*
- * This is the non-scalar case.
+ * This is the case where the third argument is not equal to -1.
  *
  * Loop linearly through each element of x, and calculate the indices for
  * that particular element.  Then, using the indices that correspond with
@@ -227,15 +338,15 @@ NhlErrorTypes conform_W( void )
         new_position -= indices[j]  * skip_x[j];
       }
       conform_pos = 0;
-      for(j = 0; j < dsizes_conform[0]; j++) {
-        conform_pos += indices[cnfrm_dims[j]] * skip_c[j];
+      for(j = 0; j < num_conform_indexes; j++) {
+        conform_pos += indices[tmp_conform_indexes[j]] * skip_c[j];
       }
       memcpy((void*)((char*)conform + i*type_size),
              (void*)((char*)tmp_md->multidval.val + conform_pos*type_size),
              type_size);
     }
   }
-  else {
+  else if(is_scalar_arr) {
 /*
  * This is the scalar case. Copy the scalar value to the output array.
  */
@@ -244,21 +355,28 @@ NhlErrorTypes conform_W( void )
              (void*)((char*)tmp_md->multidval.val),type_size);
     }
   }
+  else {
+/*
+ * This is the copy array case. Simply copy the second argument.
+ */
+    memcpy((void*)((char*)conform),(void*)((char*)tmp_md->multidval.val),size_conform*type_size);
+  }
 /*
  * Free unneeded memory.
  */
-  if(!copy_scalar) {
+  if(!is_scalar_arr && !is_same_arr) {
     NclFree(skip_x);
     NclFree(indices);
     NclFree(skip_c);
   }
+  if(conform_indexes[0] == -1 || num_degen_dims > 0) NclFree(tmp_conform_indexes);
 
 /*
  * Return values.
  */
   if(tmp_md->multidval.missing_value.has_missing) {
-    ret = NclReturnValue(conform,ndims,dsizes_x,
-                         &tmp_md->multidval.missing_value.value,
+    missing_conform = tmp_md->multidval.missing_value.value;
+    ret = NclReturnValue(conform,ndims,dsizes_x,&missing_conform,
                          tmp_md->multidval.data_type,0);
   }
   else {
@@ -284,23 +402,24 @@ NhlErrorTypes conform_dims_W( void )
   void *tmp_dsizes_x;
   ng_size_t *dsizes_x;
   NclStackEntry data;
-  int *cnfrm_dims;
+  int *conform_indexes, *tmp_conform_indexes;
   NclMultiDValData tmp_md = NULL;
   ng_size_t ndims_x;
   NclBasicDataTypes type_dsizes_x;
-  ng_size_t dsizes_conform[NCL_MAX_DIMENSIONS];
+  ng_size_t num_conform_indexes;
 /*
  * Output array variables
  */
   void *conform;
   int ndims;
+  NclScalar missing_conform;
 /*
  * various
  */
   ng_size_t i, j;
-  int scalar_tmp_md, copy_scalar = 0;
+  logical is_scalar_arr = False, is_same_arr = False, is_degen_arr = False;
   ng_size_t new_position, size_conform, conform_pos;
-  int type_size;
+  int ic, num_degen_dims, type_size;
   ng_size_t *skip_x = NULL;
   ng_size_t *skip_c = NULL;
   ng_size_t *indices = NULL;
@@ -335,70 +454,180 @@ NhlErrorTypes conform_dims_W( void )
     return(NhlFATAL);
   }
 
-  cnfrm_dims = (int*)NclGetArgValue(
+  conform_indexes = (int*)NclGetArgValue(
            2,
            3,
            NULL,
-           dsizes_conform,
+           &num_conform_indexes,
            NULL,
            NULL,
            NULL,
            DONT_CARE);
 
   dsizes_x = get_dimensions(tmp_dsizes_x,ndims_x,type_dsizes_x,"conform_dims");
+
   if(dsizes_x == NULL) 
     return(NhlFATAL);
 
 /*
- * Check if we're dealing with the special case of where the second
- * argument is a scalar, and the third argument is -1.  If this 
- * is true, then the scalar value will be copied to every 
- * element of the new array.
- */
-  scalar_tmp_md = is_scalar(tmp_md->multidval.n_dims,
-                            tmp_md->multidval.dim_sizes);
-
-  if(scalar_tmp_md && cnfrm_dims[0] == -1) copy_scalar = 1;
+ * If the array-to-be-conformed is a scalar or an array with all 
+ * degenerate dimensions, then this is a special case that we need 
+ * to handle separately. It will be treated as a single value that 
+ * needs to be propagated to whatever the dimensions are of the 
+ * array-to-be-conformed-to.
+ */ 
+  is_scalar_arr = is_scalar_array(tmp_md->multidval.n_dims,
+                                  tmp_md->multidval.dim_sizes);
 
+  is_same_arr = is_degen_arr = False;
 /*
- * If not dealing with the special scalar case, then the number of
- * dimensions of the second argument must be the same as the length
- * of the third argument.
- */
-  if(!copy_scalar && tmp_md->multidval.n_dims != dsizes_conform[0]) {
-    NhlPError(NhlFATAL,NhlEUNKNOWN,"conform_dims: The array to be conformed must have the same number of dimensions as indicated by the length of the last argument");
-    return(NhlFATAL);
-  }
-
-/*
- * If not a scalar situation, check for errors:
- *
- *    1. The dimension indices indicated by the third argument must
+ * If NOT dealing with the special conform_indexes=-1 case, then do some error checking:
+ *    1. The number of dimensions of the second argument must be the 
+ *       same as the length of the third argument.
+ *    2. The dimension indices indicated by the third argument must
  *       be in the range of the dimension indices of x (i.e. if x is
- *       only 3-dimensional, then one of the indices in the 3rd
- *       argument cannot be a "4").
- *    2. The dimensions indices indicated by the third argument must
+ *       only 3-dimensional, then none of the indices in the 3rd
+ *       argument can be greater than 3).
+ *    3. The dimensions indices indicated by the third argument must
  *       be unique and increasing.
  *    4. The dimensions sizes of the second argument must be the same
  *       as those indicated by the third argument.
  */
-  if(!copy_scalar) {
-    for(i = 0; i < dsizes_conform[0]; i++ ) {
-      if(cnfrm_dims[i] < 0 || cnfrm_dims[i] > (ndims_x-1)) {
+  if(conform_indexes[0] != -1) {
+    if(tmp_md->multidval.n_dims != num_conform_indexes) {
+      NhlPError(NhlFATAL,NhlEUNKNOWN,"conform_dims: The array to be conformed must have the same number of dimensions as indicated by the length of the last argument");
+      return(NhlFATAL);
+    }
+    for(i = 0; i < num_conform_indexes; i++ ) {
+      if(conform_indexes[i] < 0 || conform_indexes[i] > (ndims_x-1)) {
         NhlPError(NhlFATAL,NhlEUNKNOWN,"conform_dims: the third argument contains a dimension that is out-of-range of the dimensions of x");
         return(NhlFATAL);
       }
       if(i > 0) {
-        if(cnfrm_dims[i-1] >= cnfrm_dims[i]) {
+        if(conform_indexes[i-1] >= conform_indexes[i]) {
           NhlPError(NhlFATAL,NhlEUNKNOWN,"conform_dims: The dimensions specified by the third argument must be increasing");
           return(NhlFATAL);
         }
       }
-      if(dsizes_x[cnfrm_dims[i]] != tmp_md->multidval.dim_sizes[i] ) {
-        NhlPError(NhlFATAL,NhlEUNKNOWN,"conform_dims: the dimensions sizes of the second argument do not match those indicated by the third argument");
+/*
+ * In NCL V6.4.0, if any of the array-to-be-conformed dimensions are 
+ * degenerate (equal to 1), then this is considered okay no matter
+ * what the dimension size of the array-being-conformed-to is.
+ */
+      if(dsizes_x[conform_indexes[i]] != tmp_md->multidval.dim_sizes[i] && tmp_md->multidval.dim_sizes[i] != 1) {
+        NhlPError(NhlFATAL,NhlEUNKNOWN,"conform_dims: the dimension sizes of the second argument do not match those indicated by the third argument");
         return(NhlFATAL);
       }
     }
+  }
+  else {
+/*
+ * This section does some error checking for the special case of
+ *  conform_indexes = -1.
+ *
+ * You can only use -1 for the third argument if the array you are 
+ * conforming meets one of the following conditions: 
+ *
+ *    1. It's the same size as the array you are conforming to (is_same_arr).
+ *    2. It's an array with some degenerate dimensions, but the other
+ *       dimensions match the array you are conforming to (is_degen_arr).
+ *    3. It's an array with all degenerate dimensions or a scalar (is_scalar_arr)
+ *
+ *    #2 was a feature added in NCL V6.4.0. For example, you can conform
+ *    a 3 x 1 x 5 array to a 3 x 4 x 5 array, using either -1 or (/0,1,2/)
+ *    for the third argument.
+ */
+    if(tmp_md->multidval.n_dims == ndims_x) {
+      is_same_arr = is_degen_arr = True;
+      i = 0;
+      while (i < ndims_x && (is_same_arr || (!is_same_arr && is_degen_arr))) {
+        if(is_same_arr && tmp_md->multidval.dim_sizes[i] != dsizes_x[i]) {
+          is_same_arr  = False;
+          is_degen_arr = True;
+        }
+        if(is_degen_arr && tmp_md->multidval.dim_sizes[i] != dsizes_x[i] && 
+           tmp_md->multidval.dim_sizes[i] != 1) {
+          is_degen_arr = False;
+        }
+        i++;
+      }
+    }
+    if(!is_scalar_arr && !is_same_arr && !is_degen_arr) {
+      NhlPError(NhlFATAL,NhlEUNKNOWN,"conform_dims: if the third argument is -1, then second argument must either be a scalar, an array of the same dimensionality as indicated by the first argument, or an array with all singleton dimensions.");
+      return(NhlFATAL);
+    }
+  }
+
+/*
+ * If the array-to-be-conformed is not ALL degenerate dimensions, then
+ * count the number of degenerate dimensions so we can remove them later.
+ */
+  num_degen_dims = 0;
+  if(!is_scalar_arr) {
+    for(i = 0;i < tmp_md->multidval.n_dims; i++) 
+      if(tmp_md->multidval.dim_sizes[i] == 1) num_degen_dims++;
+  }
+
+/* 
+ * If there are degenerate dimensions, then remove them from the 
+ * input conform_indexes.
+ *
+ * What happens in the code below is if the array to be conformed to
+ * is 3 x 4 x 5, and the array to be conformed is 3 x 1 x 5, then
+ * the array to be conformed will be treated as a 3 x 5 array, and
+ * and hence conform_indexes will be set to (/0,2/). 
+ */
+  if(num_degen_dims > 0) {
+ /*
+  * If there are degenerate dimensions and third argument = -1,
+  * then use first argument as the dimension indexes, but 
+  * with the degenerate dimensions removed.
+  */
+    if(conform_indexes[0] == -1) {
+      num_conform_indexes = tmp_md->multidval.n_dims-num_degen_dims;
+      tmp_conform_indexes = (int*)NclMalloc(num_conform_indexes*sizeof(int));
+      ic = 0;
+      for(i = 0; i < tmp_md->multidval.n_dims; i++) {
+        if(tmp_md->multidval.dim_sizes[i] != 1) tmp_conform_indexes[ic++] = i;
+      }
+    }
+    else {
+ /*
+  * If there are degenerate dimensions and the third argument was a 
+  * list of indexes, then remove any indexes that reference 
+  * degenerate dimensions.
+  */
+      tmp_conform_indexes = (int*)NclMalloc((num_conform_indexes-num_degen_dims)*sizeof(int));
+      ic = 0;
+      for(i = 0; i < num_conform_indexes; i++) {
+        if(tmp_md->multidval.dim_sizes[i] != 1) tmp_conform_indexes[ic++] = conform_indexes[i];
+      }
+      num_conform_indexes = num_conform_indexes-num_degen_dims;
+    }
+  }
+  else {
+    if(conform_indexes[0] == -1) {
+ /*
+  * If there are no degenerate dimensions and third argument = -1,
+  * then use the dimension indexes of the first argument as the 
+  * conform dimension indexes. 
+  */
+      num_conform_indexes = tmp_md->multidval.n_dims;
+      tmp_conform_indexes = (int*)NclMalloc(num_conform_indexes*sizeof(int));
+      for(i = 0; i < tmp_md->multidval.n_dims; i++) {
+        tmp_conform_indexes[i] = i;
+      }
+    }
+    else {
+ /*
+  * If there are no degenerate dimensions and the third argument is a
+  * list of indexes, then simply point to this list of indexes.
+  */
+      tmp_conform_indexes = conform_indexes;
+    }
+  }
+
+  if(!is_scalar_arr && !is_same_arr) {
 /*
  * Create an array to hold the number of linear elements you have to
  * skip over when you increment a particular index.
@@ -410,7 +639,7 @@ NhlErrorTypes conform_dims_W( void )
  * and so on.
  */
     skip_x  = (ng_size_t*)calloc(ndims_x,sizeof(ng_size_t));
-    skip_c  = (ng_size_t*)calloc(dsizes_conform[0],sizeof(ng_size_t)); 
+    skip_c  = (ng_size_t*)calloc(num_conform_indexes,sizeof(ng_size_t)); 
     indices = (ng_size_t*)calloc(ndims_x,sizeof(ng_size_t));
 
     size_conform = dsizes_x[ndims_x-1];
@@ -420,16 +649,16 @@ NhlErrorTypes conform_dims_W( void )
       skip_x[i] = skip_x[i+1]*dsizes_x[i+1];
       size_conform  *= dsizes_x[i];
     }
-    skip_c[dsizes_conform[0]-1] = 1;
-    for(i = dsizes_conform[0]-2; i >= 0; i--) {
-      skip_c[i] = skip_c[i+1]*dsizes_x[cnfrm_dims[i+1]];
+    skip_c[num_conform_indexes-1] = 1;
+    for(i = num_conform_indexes-2; i >= 0; i--) {
+      skip_c[i] = skip_c[i+1]*dsizes_x[tmp_conform_indexes[i+1]];
     }
     ndims  = ndims_x;
   }
   else {
 /*
- * This is the scalar case. The output array will be the size of
- * the dimensions given.
+ * This is the case where the third argument is -1. The output array will
+ * be the size of the dimensions given.
  */
     ndims  = ndims_x;
     size_conform = 1;
@@ -448,9 +677,9 @@ NhlErrorTypes conform_dims_W( void )
   }
 
   type_size = tmp_md->multidval.type->type_class.size;
-  if(!copy_scalar) {
+  if(!is_scalar_arr && !is_same_arr) {
 /*
- * This is the non-scalar case.
+ * This is the case where the third argument is not equal to -1.
  *
  * Loop linearly through each element of x, and calculate the indices for
  * that particular element.  Then, using the indices that correspond with
@@ -464,15 +693,15 @@ NhlErrorTypes conform_dims_W( void )
         new_position -= indices[j]  * skip_x[j];
       }
       conform_pos = 0;
-      for(j = 0; j < dsizes_conform[0]; j++) {
-        conform_pos += indices[cnfrm_dims[j]] * skip_c[j];
+      for(j = 0; j < num_conform_indexes; j++) {
+        conform_pos += indices[tmp_conform_indexes[j]] * skip_c[j];
       }
       memcpy((void*)((char*)conform + i*type_size),
              (void*)((char*)tmp_md->multidval.val + conform_pos*type_size),
              type_size);
     }
   }
-  else {
+  else if(is_scalar_arr) {
 /*
  * This is the scalar case. Copy the scalar value to the output array.
  */
@@ -481,21 +710,28 @@ NhlErrorTypes conform_dims_W( void )
              (void*)((char*)tmp_md->multidval.val),type_size);
     }
   }
+  else {
+/*
+ * This is the copy array case. Simply copy the second argument.
+ */
+    memcpy((void*)((char*)conform),(void*)((char*)tmp_md->multidval.val),size_conform*type_size);
+  }
 /*
  * Free unneeded memory.
  */
-  if(!copy_scalar) {
+  if(!is_scalar_arr && !is_same_arr) {
     NclFree(skip_x);
     NclFree(indices);
     NclFree(skip_c);
   }
+  if(conform_indexes[0] == -1 || num_degen_dims > 0) NclFree(tmp_conform_indexes);
 
 /*
  * Return values.
  */
   if(tmp_md->multidval.missing_value.has_missing) {
-    ret = NclReturnValue(conform,ndims,dsizes_x,
-                         &tmp_md->multidval.missing_value.value,
+    missing_conform = tmp_md->multidval.missing_value.value;
+    ret = NclReturnValue(conform,ndims,dsizes_x,&missing_conform,
                          tmp_md->multidval.data_type,0);
   }
   else {
@@ -553,6 +789,7 @@ NhlErrorTypes reshape_W( void )
   void *xreshape;
   int ndims_xreshape;
   ng_size_t *dsizes_xreshape;
+  NclScalar missing_xreshape;
 
 /*
  * various
@@ -689,10 +926,9 @@ NhlErrorTypes reshape_W( void )
  * Return values.
  */
   if(tmp_md->multidval.missing_value.has_missing) {
-    ret = NclReturnValue(xreshape,ndims_xreshape,
-                         dsizes_xreshape,
-                         &tmp_md->multidval.missing_value.value,
-                         tmp_md->multidval.data_type,0);
+    missing_xreshape = tmp_md->multidval.missing_value.value;
+    ret = NclReturnValue(xreshape,ndims_xreshape,dsizes_xreshape,
+                         &missing_xreshape,tmp_md->multidval.data_type,0);
   }
   else {
     ret = NclReturnValue(xreshape,ndims_xreshape,dsizes_xreshape,
