@@ -20,6 +20,9 @@
 #include "NclBuiltIns.h"
 #include "NclHLUObj.h"
 
+/* This is for NCL V6.5.0, until we decide what to do with this function. See NCL-1042. */
+#define KDE_NAME "kde_n_test"
+
 #define min(x,y)   ((x) < (y) ? (x) : (y))
 #define max(x,y)   ((x) > (y) ? (x) : (y))
 
@@ -48,6 +51,10 @@ extern void coerce_subset_input_double_step(void *,double *,ng_size_t,ng_size_t,
 					    NclBasicDataTypes,ng_size_t,int,
 					    NclScalar*,NclScalar*);
 
+extern void coerce_subset_input_float_step(void *,float *,ng_size_t,ng_size_t,
+					   NclBasicDataTypes,ng_size_t,int,
+					   NclScalar*,NclScalar*);
+
 extern double *copy_scalar_to_array(double *, int, ng_size_t *, ng_size_t);
 
 extern float *coerce_output_float(double *, void *, ng_size_t, int);
@@ -69,6 +76,8 @@ extern void coerce_output_float_or_double_ind(void *,double *,
 extern void coerce_output_float_or_double_step(void *,double *,
 					       NclBasicDataTypes,ng_size_t,ng_size_t,ng_size_t);
 
+extern void coerce_output_float_step(void *,float *,ng_size_t,ng_size_t,ng_size_t);
+
 extern void coerce_output_step(void *,double *,NclBasicDataTypes,
 			       ng_size_t,ng_size_t,ng_size_t);
 
@@ -125,3 +134,4 @@ extern int *get_dims_for_n_funcs(int arg_num,  int num_args, NclStackEntry tmpda
 				  const char *name, int *ndims);
 
 extern int cmpdouble (const void * a, const void * b);
+
