@@ -1,12 +1,23 @@
 #include <stdio.h>
 #include "wrapper.h"
 
-extern void NGCALLF(wrf_vintrp,WRF_VINTRP)(double *, double *, double *, 
+#define ERRLEN 512
+
+/*wrf_vintrp(
+ * datain, dataout, pres,
+ * tk, qvp, ght,
+ * terrain,sfp, smsfp,
+ * vcarray, interp_levels, numlevels,&
+   icase, ew, ns, nz,
+   extrap, vcor, logp, work,
+   rmsg,errstat, errmsg)*/
+extern void NGCALLF(wrf_vintrp,WRF_VINTRP)(double *, double *, double *,
                                            double *, double *, double *, 
                                            double *, double *, double *, 
                                            double *, double *, int *, 
                                            int *, int *, int *, int *, 
-                                           int *, int *, int *, double *);
+                                           int *, int *, int *, double *,
+										   double *, int *, char *, int);
 
 extern void NGCALLF(wrf_monotonic,WRF_MONOTONIC)(double *, double *, double *, 
                                                  double *, int *, double *, 
@@ -66,13 +77,15 @@ NhlErrorTypes wrf_vintrp_W( void )
   ng_size_t dsizes_ght[NCL_MAX_DIMENSIONS];
   NclBasicDataTypes type_ght;
 
+
 /*
- * Argument # 5
- */
-  void *ter;
-  double *tmp_ter;
-  ng_size_t dsizes_ter[2];
-  NclBasicDataTypes type_ter;
+* Argument # 5
+*/
+void *ter;
+double *tmp_ter;
+int       ndims_ter;
+ng_size_t dsizes_ter[NCL_MAX_DIMENSIONS];
+NclBasicDataTypes type_ter;
 
 /*
  * Argument # 6
@@ -118,7 +131,7 @@ NhlErrorTypes wrf_vintrp_W( void )
  * Return variable
  */
   void *field_out;
-  double *tmp_field_out;
+  double *tmp_field_out, *outwork;
   ng_size_t *dsizes_field_out;
   NclScalar missing_field_out;
   NclBasicDataTypes type_field_out;
@@ -131,6 +144,8 @@ NhlErrorTypes wrf_vintrp_W( void )
   ng_size_t index_field, index_sfp, index_field_out;
   ng_size_t i, size_leftmost, size_output;
   int ininlev, inlat, inlon, inoutlev, ret;
+  int errstat;
+  char* errmsg;
 
 /*
  * Retrieve parameters.
@@ -303,7 +318,7 @@ NhlErrorTypes wrf_vintrp_W( void )
   ter = (void*)NclGetArgValue(
            5,
            14,
-           NULL,
+		   &ndims_ter,
            dsizes_ter,
            NULL,
            NULL,
@@ -313,7 +328,7 @@ NhlErrorTypes wrf_vintrp_W( void )
  * Check dimension sizes for ter.  It can either be 2D, or one fewer
  * dimensions than field.
  */
-  if(dsizes_ter[0] != nlat || dsizes_ter[1] != nlon) {
+  if(dsizes_ter[ndims_ter-2] != nlat || dsizes_ter[ndims_ter-1] != nlon) {
     NhlPError(NhlFATAL,NhlEUNKNOWN,"wrf_vintrp: The dimensions of ter must be south_north x west_east");
     return(NhlFATAL);
   }
@@ -561,14 +576,16 @@ NhlErrorTypes wrf_vintrp_W( void )
     }
   }
 
-/*
- * Coerce ter to double, if necessary.
- */
-  tmp_ter = coerce_input_double(ter,type_ter,nlatlon,0,NULL,NULL);
-  if(tmp_ter == NULL) {
-    NhlPError(NhlFATAL,NhlEUNKNOWN,"wrf_vintrp: Unable to coerce ter to double precision");
-    return(NhlFATAL);
-  }
+  /*
+   * Allocate space for tmp_ter.
+   */
+    if(type_ter != NCL_double) {
+      tmp_ter = (double *)calloc(nlatlon,sizeof(double));
+      if(tmp_ter == NULL) {
+        NhlPError(NhlFATAL,NhlEUNKNOWN,"wrf_vintrp: Unable to allocate memory for coercing ter array to double");
+        return(NhlFATAL);
+      }
+    }
 
 /*
  * Allocate space for tmp_sfp.
@@ -665,6 +682,12 @@ NhlErrorTypes wrf_vintrp_W( void )
   dsizes_field_out[ndims_field-2] = nlat;
   dsizes_field_out[ndims_field-1] = nlon;
 
+  /* Allocate space for errmsg*/
+  errmsg = (char *) calloc(ERRLEN, sizeof(char));
+
+  /* Allocate space for the work array */
+  outwork = (double *) calloc(nlatlon, sizeof(double));
+
 /*
  * Loop across leftmost dimensions and call the Fortran routine for each
  * subsection of the input arrays.
@@ -726,6 +749,17 @@ NhlErrorTypes wrf_vintrp_W( void )
       tmp_ght = &((double*)ght)[index_field];
     }
 
+/*
+ * Coerce subsection of ter (tmp_ter) to double if necessary.
+ */
+	if(type_ter != NCL_double) {
+	  coerce_subset_input_double(ter,tmp_ter,index_sfp,type_ter,
+								 nlatlon,0,NULL,NULL);
+	}
+	else {
+	  tmp_ter = &((double*)ter)[index_sfp];
+	}
+
 /*
  * Coerce subsection of sfp (tmp_sfp) to double if necessary.
  */
@@ -770,12 +804,24 @@ NhlErrorTypes wrf_vintrp_W( void )
 /*
  * Call the Fortran routine.
  */
+    errstat = 0;
+    /*wrf_vintrp(datain, dataout, pres, tk, qvp, ght, terrain,&
+                      sfp, smsfp, vcarray, interp_levels, numlevels,&
+                      icase, ew, ns, nz, extrap, vcor, logp, tempout, rmsg,&
+                      errstat, errmsg)*/
     NGCALLF(wrf_vintrp,WRF_VINTRP)(tmp_field, tmp_field_out, tmp_pres,
                                    tmp_tk, tmp_qvp, tmp_ght, tmp_ter, 
                                    tmp_sfp, tmp_smsfp, tmp_vcarray, 
                                    tmp_intrp_levels, &inoutlev, icase, 
                                    &inlon, &inlat, &ininlev, extrap, vcor, 
-                                   logp, &missing_dbl_field.doubleval);
+                                   logp, outwork,
+								   &missing_dbl_field.doubleval,
+								   &errstat, errmsg, ERRLEN);
+    /* Terminate if there was an error */
+	if (errstat != 0) {
+		fprintf(stderr, errmsg);
+		exit(errstat);
+	}
 
 /*
  * Coerce output back to float if necessary.
@@ -805,6 +851,9 @@ NhlErrorTypes wrf_vintrp_W( void )
   if(type_intrp_levels != NCL_double) NclFree(tmp_intrp_levels);
   if(type_field_out    != NCL_double) NclFree(tmp_field_out);
 
+  NclFree(errmsg);
+  NclFree(outwork);
+
 /*
  * Return value back to NCL script.
  */
@@ -844,7 +893,9 @@ NhlErrorTypes wrf_monotonic_W( void )
  */
   void *cor;
   double *tmp_cor;
-  ng_size_t dsizes_cor[2];
+  /*ng_size_t dsizes_cor[2];*/
+  int       ndims_cor;
+  ng_size_t dsizes_cor[NCL_MAX_DIMENSIONS];
   NclBasicDataTypes type_cor;
 
 /*
@@ -874,7 +925,7 @@ NhlErrorTypes wrf_monotonic_W( void )
  * Various
  */
   ng_size_t nlev, nlat, nlon, nlevlatlon, nlatlon;
-  ng_size_t i, index_x, size_leftmost, size_output;
+  ng_size_t i, index_x, index_cor, size_leftmost, size_output;
   int inlev, inlat, inlon, ret;
 /*
  * Retrieve parameters.
@@ -953,14 +1004,14 @@ NhlErrorTypes wrf_monotonic_W( void )
   cor = (void*)NclGetArgValue(
            2,
            6,
-           NULL,
+		   &ndims_cor,
            dsizes_cor,
            NULL,
            NULL,
            &type_cor,
            DONT_CARE);
 
-  if(dsizes_cor[0] != nlat || dsizes_cor[1] != nlon) {
+  if(dsizes_cor[ndims_cor-2] != nlat || dsizes_cor[ndims_cor-1] != nlon) {
     NhlPError(NhlFATAL,NhlEUNKNOWN,"wrf_vintrp: The dimensions of cor must be south_north x west_east");
     return(NhlFATAL);
   }
@@ -1043,13 +1094,16 @@ NhlErrorTypes wrf_monotonic_W( void )
     }
   }
 /*
- * Coerce cor to double, if necessary.
+ * Allocate space for tmp_cor
  */
-  tmp_cor = coerce_input_double(cor,type_cor,nlatlon,0,NULL,NULL);
-  if(tmp_cor == NULL) {
-    NhlPError(NhlFATAL,NhlEUNKNOWN,"wrf_monotonic: Unable to coerce cor to double precision");
-    return(NhlFATAL);
-  }
+  if(type_cor != NCL_double) {
+      tmp_cor = (double *)calloc(nlatlon,sizeof(double));
+      if(tmp_cor == NULL) {
+        NhlPError(NhlFATAL,NhlEUNKNOWN,"wrf_monotonic: Unable to allocate memory for coercing input array to double");
+        return(NhlFATAL);
+      }
+    }
+
 
 /*
  * Allocate space for tmp_delta.
@@ -1089,6 +1143,7 @@ NhlErrorTypes wrf_monotonic_W( void )
  * subsection of the input arrays.
  */
   index_x = 0;
+  index_cor = 0;
   for(i = 0; i < size_leftmost; i++) {
 /*
  * Coerce subsection of x (tmp_x) to double if necessary.
@@ -1110,6 +1165,16 @@ NhlErrorTypes wrf_monotonic_W( void )
       tmp_pres = &((double*)pres)[index_x];
     }
 
+/*
+ * Coerce subsection of cor (tmp_cor) to double if necessary.
+ */
+	if(type_pres != NCL_double) {
+	  coerce_subset_input_double(cor,tmp_cor,index_cor,type_cor,nlatlon,0,NULL,NULL);
+	}
+	else {
+	  tmp_cor = &((double*)cor)[index_cor];
+	}
+
 /*
  * Point temporary output array to void output array if appropriate.
  */
@@ -1128,6 +1193,7 @@ NhlErrorTypes wrf_monotonic_W( void )
       coerce_output_float_only(xout,tmp_xout,nlevlatlon,index_x);
     }
     index_x += nlevlatlon;
+    index_cor += nlatlon;
   }
 
 /*
