@@ -21,6 +21,7 @@
  */
 
 #include <string.h>
+#include <ctype.h>
 #include "AdvancedFileSupport.h"
 
 NclQuark *GetGrpVarNames(void *therec, int *num_vars)
@@ -429,6 +430,37 @@ NclFileAttNode *GetAttInfoFromVarNode(NclFileVarNode *varnode, NclQuark att_name
     return(tmp);
 }
 
+void _NclCopyGroupOptions(NclFileGrpNode *grpnode, NclFileGrpNode *rootgrpnode)
+{
+    int n = 0;
+    size_t typesize = 0;
+    if(NULL != grpnode->options)
+	return;
+
+    grpnode->n_options = rootgrpnode->n_options;
+
+    if(grpnode->n_options)
+    {
+        grpnode->options = (NCLOptions *)NclCalloc(grpnode->n_options, sizeof(NCLOptions));
+        assert(grpnode->options);
+
+        for(n = 0; n < grpnode->n_options; ++n)
+        {
+            grpnode->options[n].name = rootgrpnode->options[n].name;
+            grpnode->options[n].size = rootgrpnode->options[n].size;
+            grpnode->options[n].type = rootgrpnode->options[n].type;
+            grpnode->options[n].values = NULL;
+            if(rootgrpnode->options[n].size)
+            {
+                typesize = _NclSizeOf(rootgrpnode->options[n].type);
+                grpnode->options[n].values = (void*)NclCalloc(rootgrpnode->options[n].size, typesize);
+                memcpy(grpnode->options[n].values, rootgrpnode->options[n].values,
+                       grpnode->options[n].size * typesize);
+            }
+        }
+    }
+}
+
 NhlErrorTypes AddNewGrp(void *rec, NclQuark grpname, size_t id)
 {
     NclFileGrpNode *rootgrpnode = (NclFileGrpNode *) rec;
@@ -490,11 +522,6 @@ NhlErrorTypes AddNewGrp(void *rec, NclQuark grpname, size_t id)
     }
     grpnode->real_name = NrmStringToQuark(buffer);
 
-    grpnode->n_options = rootgrpnode->n_options;
-    grpnode->options = (NCLOptions *)NclCalloc(rootgrpnode->n_options, sizeof(NCLOptions));
-    assert(grpnode->options);
-    memcpy(grpnode->options, rootgrpnode->options, rootgrpnode->n_options * sizeof(NCLOptions));
-
     grpnode->chunk_dim_rec = NULL;
     grpnode->unlimit_dim_rec = NULL;
     grpnode->dim_rec = NULL;
@@ -505,6 +532,8 @@ NhlErrorTypes AddNewGrp(void *rec, NclQuark grpname, size_t id)
     grpnode->udt_rec = NULL;
     grpnode->parent = rootgrpnode;
 
+    _NclCopyGroupOptions(grpnode, rootgrpnode);
+
     return ret;
 }
 
@@ -618,15 +647,13 @@ void _Ncl_add_udt(NclFileUDTRecord **rootudtrec,
     udtnode->max_fields = nfields;
     udtnode->n_fields = nfields;
 
-    udtnode->mem_name = (NclQuark *)NclCalloc(nfields, sizeof(NclQuark));
-    assert(udtnode->mem_name);
-    udtnode->mem_type = (NclBasicDataTypes *)NclCalloc(nfields, sizeof(NclBasicDataTypes));
-    assert(udtnode->mem_type);
-
+    udtnode->fields = (NclFileUDTField *) NclCalloc(nfields, sizeof(NclFileUDTField));
+    assert(udtnode->fields);
+						    
     for(n = 0; n < nfields; n++)
     {
-        udtnode->mem_name[n] = mem_name[n];
-        udtnode->mem_type[n] = mem_type[n];
+        udtnode->fields[n].field_name = mem_name[n];
+        udtnode->fields[n].field_type = mem_type[n];
     }
 
     udtrec->n_udts ++;
@@ -639,8 +666,8 @@ void *GetCachedValue(NclFileVarNode *varnode,
                      long start, long finish, long stride, void *storage)
 {
     long i,j;
-    int tsize = varnode->the_nc_type < 1 ? 1 : nctypelen(varnode->the_nc_type);
-
+    /*int tsize = varnode->the_nc_type < 1 ? 1 : nctypelen(varnode->the_nc_type);*/
+    int tsize = _NclSizeOf(varnode->type);
     for (j = 0, i = start; i <= finish; i += stride,j++)
     {
         memcpy(((char*)storage) + j * tsize,((char *)varnode->value) + i * tsize,tsize);
@@ -648,3 +675,50 @@ void *GetCachedValue(NclFileVarNode *varnode,
     return storage;
 }
 
+void _NclCopyOption(NCLOptions *option, NclQuark name,
+                    NclBasicDataTypes data_type, int n_items, void *values)
+{
+    short need_realloc = 0;
+    size_t nsz = 1;
+
+    if(name != option->name)
+    {
+        fprintf(stderr, "\nWARINING: In copy_option, file: %s, line: %d\n", __FILE__, __LINE__);
+        fprintf(stderr, "\tsource name <%s> is not same as target name <%s>\n",
+			   NrmQuarkToString(name), NrmQuarkToString(option->name));
+        return;
+    }
+
+    if(n_items != option->size)
+    {
+        need_realloc = 1;
+      /*
+       *fprintf(stderr, "\nWARINING: In copy_option, file: %s, line: %d\n", __FILE__, __LINE__);
+       *fprintf(stderr, "\tsource size: %d is not equal to target size: %d\n", n_items, option->size);
+       */
+        option->size = n_items;
+        NclFree(option->values);
+    }
+
+    if(data_type != option->type)
+    {
+        need_realloc = 1;
+
+      /*
+       *fprintf(stderr, "\nWARINING: In copy_option, file: %s, line: %d\n", __FILE__, __LINE__);
+       *fprintf(stderr, "\tsource type: <%s> is not equal to target type: <%s>\n",
+       *	           _NclBasicDataTypeToName(data_type), _NclBasicDataTypeToName(option->type));
+       */
+
+        option->type = data_type;
+    }
+
+    nsz = n_items * _NclSizeOf(data_type);
+    if(NULL == option->values)
+        option->values = (void*)NclMalloc(nsz);
+    else if(need_realloc)
+        option->values = (void*)NclRealloc(option->values, nsz);
+
+    memcpy(option->values, values, nsz);
+}
+
