@@ -340,6 +340,34 @@ NclQuark *_split_string2quark(NclQuark qn, int *ns)
     return sq;
 }
 
+/*
+ * Updates the dimension info
+ */
+
+NhlErrorTypes UpdateGroupDims(NclGroup *group_out, NclFile thefile)
+{
+	NclQuark *name_list;
+	int n_names;
+	int i;
+	int index = -1;
+
+	name_list = (*thefile->file.format_funcs->get_dim_names)(thefile->file.private_rec,&n_names);
+	group_out->file.n_file_dims = n_names;
+	for(i = 0; i < n_names; i++){
+		if (group_out->file.file_dim_info[i])
+			NclFree(group_out->file.file_dim_info[i]);
+		group_out->file.file_dim_info[i] = (thefile->file.format_funcs->get_dim_info)
+			(thefile->file.private_rec,name_list[i]);
+		if(thefile->file.n_vars)
+		    index = _NclFileIsVar(thefile,name_list[i]);
+		if(index > -1 && thefile->file.var_info[index]->num_dimensions == 1) {
+			group_out->file.coord_vars[i] = thefile->file.var_info[index];
+		}
+	}
+	NclFree((void*)name_list);
+	return NhlNOERROR;
+}
+
 NclGroup *_NclGroupCreate
 #if    NhlNeedProto
 (NclObj  inst, NclObjClass theclass, NclObjTypes obj_type, unsigned int obj_type_mask, NclStatus status, NclFile file_in, NclQuark group_name)
@@ -385,7 +413,7 @@ NclQuark group_name;
 
     if(inst == NULL)
     {
-        group_out = (NclFile)NclMalloc(sizeof(NclFileRec));
+        group_out = (NclFile)NclCalloc(1, sizeof(NclFileRec));
         group_out_free = 1;
     }
     else
@@ -403,11 +431,11 @@ NclQuark group_name;
     initializeGroup(group_out);
 
     group_out->file.fname = file_in->file.fname;
-    group_out->file.fpath = file_in->file.fpath;
+    group_out->file.fpath = NrmStringToQuark(_NGResolvePath(NrmQuarkToString(file_in->file.fpath)));
     group_out->file.file_ext_q = file_in->file.file_ext_q;
     group_out->file.wr_status = file_in->file.wr_status;
     group_out->file.file_format = file_in->file.file_format;
-
+    group_out->file.advanced_file_structure = 0;
     group_out->file.format_funcs = _NclGetFormatFuncs(group_out->file.file_ext_q);
     group_out->file.private_rec = (*group_out->file.format_funcs->initialize_file_rec)(&group_out->file.file_format);
 
@@ -424,6 +452,12 @@ NclQuark group_name;
                                    group_out->file.fpath, group_out->file.wr_status);
 
     group_out->file.n_file_dims = file_in->file.n_file_dims;
+    group_out->file.n_file_atts = file_in->file.n_file_atts;
+
+    _NclReallocFilePart(&(group_out->file), -1, -1,
+                        group_out->file.n_file_dims, group_out->file.n_file_atts);
+
+    UpdateGroupDims(group_out, file_in);
   /*
    *for(i = 0; i < group_out->file.n_file_dims; i++)
    *{
@@ -432,10 +466,6 @@ NclQuark group_name;
    *}
    */
 
-    UpdateDims(group_out);
-
-    group_out->file.n_file_atts = file_in->file.n_file_atts;
-
     for(j = 0; j < file_in->file.n_file_atts; j++)
     {
         group_out->file.file_atts[j] = (struct _NclFAttRec *)NclMalloc(sizeof(struct _NclFAttRec));
@@ -523,6 +553,8 @@ NclQuark group_name;
 
         if(inqnumb != tmpqnumb)
         {
+	    if(n_grps >= group_out->file.max_grps)
+                _NclReallocFilePart(&(group_out->file), n_grps, -1, -1, -1);
             group_out->file.grp_info[n_grps] = getGrpRec(file_in->file.grp_info[i]);
             n_grps++;
         }
@@ -571,14 +603,23 @@ NclQuark group_name;
         if(!found)
             continue;
 
+	if(n_vars >= group_out->file.max_vars)
+            _NclReallocFilePart(&(group_out->file), -1, n_vars, -1, -1);
+
         group_out->file.var_info[n_vars] = getVarRec(file_in->file.var_info[i]);
         copyAttributes(&(group_out->file.var_att_info[n_vars]),
                        file_in->file.var_att_info[i]);
+
+      /*
+       *UpdateCoordInfo(group_out, group_out->file.var_info[n_vars]->var_name_quark);
+       */
         n_vars++;
     }
 
     group_out->file.n_vars = n_vars;
 
+    _NclReallocFilePart(&(group_out->file), n_grps, n_vars, -1, -1);
+
     setVarAtts(group_out);
 
     (void)_NclObjCreate((NclObj)group_out,class_ptr,obj_type,
